@@ -86,16 +86,28 @@ Get_Fragment( void )
 	  return( FALSE );
   }
 
-
   /* Goertzel block size depends on Morse speed */
   block_size = detector_data.frag_len;
 
   /* Buffer dsp samples of input signal for a fragment */
   for( frag_timer = 0; frag_timer < detector_data.frag_len; frag_timer++ )
   {
-	if( !Signal_Sample(
-		  &detector_data.samples_buff[detector_data.samples_buff_idx]) )
-	return( FALSE );
+#ifdef HAVE_LIBPERSEUS_SDR
+	if( rc_data.receiver_type == PERSEUS )
+	{
+	  /* Get new sample from Perseus DSP */
+	  if( !Demodulate_CW(
+			&detector_data.samples_buff[detector_data.samples_buff_idx]) )
+		return( FALSE );
+	}
+	else
+#endif
+	{
+	  /* Get new sample from DSP buffer */
+	  if( !Signal_Sample(
+			&detector_data.samples_buff[detector_data.samples_buff_idx]) )
+		return( FALSE );
+	}
 
 	/* Advance/Reset circular buffers' index */
 	detector_data.samples_buff_idx++;
@@ -306,8 +318,7 @@ Initialize_Detector( void )
 
   /* Goertzel detector coefficients */
   double w = 2.0 * M_PI *
-	(double)rc_data.tone_freq /
-	(double)rc_data.dsp_rate;
+	(double)rc_data.tone_freq /	(double)rc_data.dsp_rate;
   detector_data.cosw  = cos(w);
   detector_data.sinw  = sin(w);
   detector_data.coeff = 2.0 * detector_data.cosw;
