@@ -16,12 +16,11 @@
 #define DISPLAY_H	1
 
 #include "common.h"
-#include "dft.h"
 #include "decode.h"
 
 /* Length and multiplier of amplitude averaging window  */
-#define AMPL_AVE_WIN		2
-#define AMPL_AVE_MUL		1
+#define AMPL_AVE_WIN		3
+#define AMPL_AVE_MUL		2
 
 /* Some colors used in plotting */
 #define RGB_GREEN		0.0, 1.0, 0.0
@@ -30,4 +29,8 @@
 
 #define CAIRO_LINE_WIDTH	1.5
 
+/* Scale FFT output bins */
+#define IFFT_SCALE		64
+
 #endif
+
