@@ -21,31 +21,35 @@
 /* Object ID's for GtkBuilder */
 #define ERROR_DIALOG_IDS \
 "error_dialog", \
-"err_quit_button", \
-"err_ok_button", \
+"error_quit_button", \
+"error_ok_button", \
 "error_message", \
 NULL
 
 #define MAIN_WINDOW_IDS \
-"level_adj", \
-"ratio_adj", \
-"wpm_adj", \
+"freq_adjustment", \
+"level_adjustment", \
+"ratio_adjustment", \
+"wpm_adjustment", \
 "main_window", \
 "rx_scrolledwindow", \
 "rx_textview", \
-"scope", \
+"scope_drawingarea", \
 "scope_label", \
-"receive", \
-"clearwin", \
-"wpm", \
-"speed", \
-"squelch", \
-"ratio", \
+"receive_togglebutton", \
+"frequency_spinbutton", \
+"bandwidth_combobox", \
+"clear_button", \
+"receiver_combobox", \
+"auto_checkbutton", \
+"wpm_spinbutton", \
 "signal_radiobutton", \
-"stop_radiobutton", \
 "level_radiobutton", \
 "ratio_radiobutton", \
-"waterfall", \
+"stop_radiobutton", \
+"squelch_spinbutton", \
+"ratio_spinbutton", \
+"waterfall_drawingarea", \
 NULL
 
 #endif
